Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PressNumber ¶
func PressNumber(k Key) bool
Types ¶
type VirtualKey ¶
type VirtualKey struct {
VirKey Key
Button
// contains filtered or unexported fields
}
func NewVirtualKey ¶
func NewVirtualKey(parent Container) (*VirtualKey, error)
func (*VirtualKey) CreateLayoutItem ¶
func (k *VirtualKey) CreateLayoutItem(ctx *LayoutContext) LayoutItem
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
actions
command
|
|
|
apptabs
command
|
|
|
clipboard
command
|
|
|
databinding
command
|
|
|
drawing
command
|
|
|
dropfiles
command
|
|
|
externalwidgets
command
|
|
|
filebrowser
command
|
|
|
gradientcomposite
command
|
|
|
imageicon
command
|
|
|
imageview
command
|
|
|
imageviewer
command
|
|
|
label
command
|
|
|
linklabel
command
|
|
|
listbox
command
|
|
|
listbox_ownerdrawing
command
|
|
|
logview
command
|
|
|
multiplepages
command
|
|
|
notifyicon
command
|
|
|
progressindicator
command
|
|
|
radiobutton
command
|
|
|
settings
command
|
|
|
slider
command
|
|
|
statusbar
command
This example demonstrates the status bar, including a size gripper attached to the bottom of the main window.
|
This example demonstrates the status bar, including a size gripper attached to the bottom of the main window. |
|
tableview
command
|
|
|
virtualkey
command
|
|
|
webview
command
|
|
|
webview_events
command
|
|
|
tools
|
|
|
ui2walk
command
|
Click to show internal directories.
Click to hide internal directories.